#! /bin/sh
#------------------------------------------------------------------------------
# /usr/local/htdocs/list.sh - show package details
#
# Copyright (c) 2003-2010  Andreas Pohl, apohl(at)ibp-consult(dot)com
# Copyright (c) 2011-2018  The Eisfair Team, team(at)eisfair(dot)org
#
# Creation:     2006-07-01 mh
# Last Update:  $Id: list.sh 51907 2018-02-28 17:09:12Z jed $
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version..
#------------------------------------------------------------------------------

# load eislib etc.
. /var/install/include/eislib

myname=$1
package=$2

#exec 2>/tmp/list-trace-$$.log
#set -x

#------------------------------------------------------------------------------
# echo at specific cordinates
#
# $1 - y-position
# $2 - x-position
#------------------------------------------------------------------------------
echoyx ()
{
    echo -e "\033[$1;$2H\c"
    shift; shift
    echo -e "$*\c"
}

#------------------------------------------------------------------------------
# goto specific cordinates
#
# $1 - y-position
# $2 - x-position
#------------------------------------------------------------------------------
gotoyx ()
{
    echo -e "\033[$1;$2H\c"
}

#------------------------------------------------------------------------------
# read old package information
#---------------yy---------------------------------------------------------------
read_old_package_info ()
{
    file=$1

    while read line
    do
        case "$line" in
            "<package>"*)
                set -- $line
                package="$2"
                ;;
            "<description>"*)
                set -- $line
                shift
                description="$*"
                ;;
            "<version>"*)
                set -- $line
                version="$2"
                ;;
            "<date>"*)
                set -- $line
                date="$2"
                ;;
            "<author>"*)
                set -- $line
                shift
                author="$*"
                ;;
            *)
                ;;
        esac
    done < $file
}

#------------------------------------------------------------------------------
# read package information
#------------------------------------------------------------------------------
read_package_info ()
{
    file=$1
    description=''
    description_active=false
    while read a
    do
        case "$a" in
            "<name>"*)
                package=`echo "$a" | sed 's#</*name>##g'`
                ;;
            "<version>"*)
                version=`echo "$a" | sed 's#</*version>##g'`
                ;;
            "<date>"*)
                date=`echo "$a" | sed 's#</*date>##g'`
                ;;
            "<description>"*)
                description_active=true
                ;;
            "</description>"*)
                description_active=false
                ;;
            "</package>"*)
                ;;
            *)
                if [ "$description_active" = true ]
                then
                    description= "test"
                fi
                ;;
        esac
    done < $file
}

#------------------------------------------------------------------------------
# display package information
#------------------------------------------------------------------------------
display_package_info ()
{
    file=$1

    while read a
    do
        case "$a" in
            "<package>"*)
                ;;
            "<name>"*)
                name=`echo "$a" | sed 's#</*name>##g'`
                echo "  Name:      "$name
                ;;
            "<short>"*)
                package=`echo "$a" | sed 's#</*short>##g'`
                echo "  Package:   "$package
                ;;
            "<version>"*)
                version=`echo "$a" | sed 's#</*version>##g'`
                normalize_version $version
                echo "  Version:   "$version
                ;;
            "<date>"*)
                date=`echo "$a" | sed 's#</*date>##g'`
                echo "  Date:      "$date
                ;;
            "<author>"*)
                author=`echo "$a" | sed 's#</*author>##g'`
                echo "  Author:    "$author
                ;;
            "<status>"*)
                status=`echo "$a" | sed 's#</*status>##g'`
                echo "  Status:    "$status
                ;;
            "<section>"*)
                section=`echo "$a" | sed 's#</*section>##g'`
                echo "  Section:   "$section
                ;;
            "<source>"*)
                source=`echo "$a" | sed 's#</*source>##g'`
                echo "  Source:    "$source
                ;;
            "<require>"*)
                require=`echo "$a" | sed 's#</*require>##g'`
                echo "  Require:   "$require
                ;;
            "<description>"*)
                description_active=true
                ;;
            "</description>"*)
                description_active=false
                ;;
            "</package>"*)
                ;;
            *)
                if [ "$description_active" = true ]
                then
                    echo "  $a"
                fi
                ;;
        esac
    done <$file
}

#------------------------------------------------------------------------------
# normalize version number
#------------------------------------------------------------------------------
normalize_version ()
{
    v=$1

    case $v in
        1.0beta)
            v=0.90.0
            ;;
        1.0beta-patch-*)
            IFS='-'
            set -- $v
            unset IFS
            v=0.90.$3
            ;;
    esac

    case "$v" in
        [0-9]*.[0-9]*.[0-9]*)
            IFS='.'
            set -- $v
            unset IFS
            major=$1
            minor=$2
            revision=$3
            ;;
        [0-9]*.[0-9]*)
            IFS='.'
            set -- $v
            unset IFS
            major=$1
            minor=$2
            revision=0
            ;;
        *)
            major=0
            minor=0
            revision=0
            ;;
    esac
    version=$major.$minor.$revision
}

#==============================================================================
# main
#==============================================================================
while [ 1 ]
do
    if [ -z "$package" ]
    then
        col_table=`cat table`
        echo "$col_table"

        row=0
        n=0
        rc=1

        for j in /var/install/packages/*
        do
            n=`expr $n + 1`

            grep '<short>' $j >/dev/null
            if [ $? = 0 ]
            then
                read_package_info $j
            else
                read_old_package_info $j
            fi

            normalize_version $version

            eval package_$n='"$j"'
            row=`expr $row + 1`

            if [ $rc = 1 ]
            then
                bgcolor='E8E8E8'
                rc=0
            else
                bgcolor='#B3B3B3'
                rc=1
            fi

            echo "<tr bgcolor=\"$bgcolor\">"
            echo "<td bgcolor=\"$bgcolor\">$n. <a href=\"$myname?package=$package\" target=\"_details\"  >$package</a> </td>"
            echo "<td>$version</td>"
            echo "<td>$date</td>"
            echo "<td bgcolor=\"$bgcolor\"> <a href=\"http://www.pack-eis.de/index.php?p=$package\" target=\"_details\"  >http://www.pack-eis.de/index.php?p=$package</a> </td>"
            echo " </tr>"

            if [ $row = 5 ]
            then
                echo "<tr><td><br> </td></tr>"
                row=0
            fi
        done
        echo "</table>"
        exit
    else
        file='/var/install/packages/'$package
        grep '<short>' $file >/dev/null

        if [ $? = 0 ]
        then
            display_package_info $file
        else
            read_old_package_info $file
            normalize_version $version
            echo "  Package:        $package"
            echo "  Description:    $description"
            echo "  Version:        $version"
            echo "  Date:           $date"
            echo "  Author:         $author"
        fi
        exit
    fi

    echoyx 23 1 "More infos of package (1-$n, 0=Exit) "
    read a

    if [ -n "$a" -a "$a" != '0' ]
    then
        eval file='$package_'$a

        clrhome
        mecho --info "Package information"
        echo

        grep '<short>' $file >/dev/null
        if [ $? = 0 ]
        then
            echo; echo
            display_package_info $file
            echo; echo
        else
            read_old_package_info $file
            normalize_version $version

            echo; echo; echo; echo; echo; echo
            echo "           Package:        $package"
            echo
            echo "           Description:    $description"
            echo
            echo "           Version:        $version"
            echo
            echo "           Date:           $date"
            echo
            echo "           Author:         $author"
            echo; echo; echo; echo; echo
        fi

        gotoyx 23 1

        anykey
    else
        if [ "$a" = "0" ]
        then
            exit 1
        fi
        break
    fi
done

#==============================================================================
# end
#==============================================================================
exit 0
